Crate dijkstra_suite

Crate dijkstra_suite 

A Dijkstra’s algorithm implementation that aims to be simple to use and fast to run

** simple.** nodes id and its cost are defined by yuor own types

[dependencies]
dijkstra-suite = "0.1.0-alpha.0"

Usage

Just import the add() function and call it

use dijkstra_suite::add;

let sum = add(400, 20);

Functions

add