DijkstraError

Enum DijkstraError 

#[non_exhaustive]
pub enum DijkstraError { GenericZeroError(String), DistanceEntryNotFound(String), ComputePathError(String), GraphNodeNotFound(String), StrategyError(String), }
centralized error type

The DijkstraError error type

This enum is a centralized error type used throughout the library It implements the Error trait manually so to avoid an external dependency

Example

Main function dijkstra_path() as well as internals like DistanceFromSource::compute_path() uses DijkstraError:

use dijkstra_suite::error::DijkstraError;
use dijkstra_suite::compute::DistanceFromSource;

let mut distances = DistanceFromSource::default();

distances.set_distance((0, 0), 0, None);
let node_error = DijkstraError::ComputePathError("end node not found".into());

let result = distances.compute_path((0, 2));

assert_eq!(result, Err(node_error));

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


GenericZeroError(String)

error while generating the generic zero



DistanceEntryNotFound(String)



ComputePathError(String)



GraphNodeNotFound(String)



StrategyError(String)